"""
Tests of `openscm_zenodo.zenodo`
"""

from __future__ import annotations

from openscm_zenodo.zenodo import ZenodoInteractor


def test_token_hidden():
    zi = ZenodoInteractor(token="special")  # noqa: S106

    assert "special" not in str(zi)
    assert "***" in str(zi)
    assert "special" not in repr(zi)
    assert "***" in repr(zi)



"""
Command-line tool for uploading to zenodo
"""

import importlib.metadata

from loguru import logger

from openscm_zenodo.zenodo import (
    ZenodoDomain,
    ZenodoInteractor,
    create_new_version,
    get_reserved_doi,
    retrieve_bibtex_entry,
    retrieve_metadata,
)

logger.disable("openscm_zenodo")

__version__ = importlib.metadata.version("openscm_zenodo")

__all__ = [
    "ZenodoDomain",
    "ZenodoInteractor",
    "create_new_version",
    "get_reserved_doi",
    "retrieve_bibtex_entry",
    "retrieve_metadata",
]
